Max (thispatcher) compiler-
Max (thispatcher) compiler-
(build-connection {:keys [router-id]} routetable type id idx connections)(build-connections env routetable nodes)(build-event-channels {:keys [handler-id]} nodes)(build-node-connections env routetable {:keys [inlets outlets id]})(build-object node)(build-object-set-arg node)(build-objects nodes)(build-router {:keys [router-id handler-id]} nodes)Compiles a jax object into a collection of instructions to be sent to a thispatcher obj
Compiles a jax object into a collection of instructions to be sent to a thispatcher obj
(default-env inst)(id->str match)(route-defaults route-obj nodes)(serialize-message-arg arg)(serialize-message-args args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |